@@ -9,6 +9,7 @@ from typing import Any, Dict, List, Optional, Tuple
 import annofabapi
 import annofabapi.utils
 import requests
+from annofabapi.dataclass.task import Task
 from annofabapi.models import InputDataType, ProjectMemberRole, TaskPhase, TaskStatus
 
 import annofabcli
@@ -20,6 +21,7 @@ from annofabcli.common.cli import (
     ArgumentParser,
     build_annofabapi_resource_and_login,
 )
+from annofabcli.common.facade import TaskQuery, match_task_with_task_query
 
 logger = logging.getLogger(__name__)
 
@@ -125,6 +127,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         assign_last_annotator: bool,
         assigned_annotator_user_id: Optional[str],
         cancel_acceptance: bool = False,
+        task_query: Optional[TaskQuery] = None,
     ):
         task_id = task["task_id"]
         if task["phase"] == TaskPhase.ANNOTATION.value:
@@ -142,6 +145,10 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
             )
             return False
 
+        if match_task_with_task_query(Task.from_dict(task), task_query):
+            logger.debug(f"task_id = {task_id} : TaskQueryの条件にマッチしないため、スキップします。")
+            return False
+
         if not self.confirm_reject_task(
             task_id, assign_last_annotator=assign_last_annotator, assigned_annotator_user_id=assigned_annotator_user_id
         ):
@@ -167,6 +174,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         assign_last_annotator: bool = True,
         assigned_annotator_user_id: Optional[str] = None,
         cancel_acceptance: bool = False,
+        task_query: Optional[TaskQuery] = None,
         task_index: Optional[int] = None,
     ) -> bool:
         """
@@ -201,6 +209,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
             assign_last_annotator=assign_last_annotator,
             assigned_annotator_user_id=assigned_annotator_user_id,
             cancel_acceptance=cancel_acceptance,
+            task_query=task_query,
         ):
             return False
 
@@ -257,6 +266,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         assign_last_annotator: bool = True,
         assigned_annotator_user_id: Optional[str] = None,
         cancel_acceptance: bool = False,
+        task_query: Optional[TaskQuery] = None,
     ) -> bool:
         task_index, task_id = tpl
         return self.reject_task_with_adding_comment(
@@ -268,6 +278,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
             assign_last_annotator=assign_last_annotator,
             assigned_annotator_user_id=assigned_annotator_user_id,
             cancel_acceptance=cancel_acceptance,
+            task_query=task_query,
         )
 
     def reject_task_list(
@@ -278,8 +289,11 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
         assign_last_annotator: bool = True,
         assigned_annotator_user_id: Optional[str] = None,
         cancel_acceptance: bool = False,
+        task_query: Optional[TaskQuery] = None,
         parallelism: Optional[int] = None,
     ) -> None:
+        if task_query is not None:
+            task_query = self.facade.set_account_id_of_task_query(project_id, task_query)
 
         project, _ = self.service.api.get_project(project_id)
         project_input_data_type = InputDataType(project["input_data_type"])
@@ -295,6 +309,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
                 assign_last_annotator=assign_last_annotator,
                 assigned_annotator_user_id=assigned_annotator_user_id,
                 cancel_acceptance=cancel_acceptance,
+                task_query=task_query,
             )
             with multiprocessing.Pool(parallelism) as pool:
                 result_bool_list = pool.map(partial_func, enumerate(task_id_list))
@@ -313,6 +328,7 @@ class RejectTasksMain(AbstracCommandCinfirmInterface):
                     assign_last_annotator=assign_last_annotator,
                     assigned_annotator_user_id=assigned_annotator_user_id,
                     cancel_acceptance=cancel_acceptance,
+                    task_query=task_query,
                 )
                 if result:
                     success_count += 1
@@ -344,6 +360,9 @@ class RejectTasks(AbstractCommandLineInterface):
 
         super().validate_project(args.project_id, [ProjectMemberRole.OWNER])
 
+        dict_task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
+        task_query: Optional[TaskQuery] = TaskQuery.from_dict(dict_task_query) if dict_task_query is not None else None
+
         main_obj = RejectTasksMain(self.service, all_yes=self.all_yes)
         main_obj.reject_task_list(
             args.project_id,
@@ -352,6 +371,7 @@ class RejectTasks(AbstractCommandLineInterface):
             assign_last_annotator=assign_last_annotator,
             assigned_annotator_user_id=args.assigned_annotator_user_id,
             cancel_acceptance=args.cancel_acceptance,
+            task_query=task_query,
             parallelism=args.parallelism,
         )
 
@@ -390,6 +410,8 @@ def parse_args(parser: argparse.ArgumentParser):
 
     parser.add_argument("--cancel_acceptance", action="store_true", help="受入完了状態を取り消して、タスクを差し戻します。")
 
+    argument_parser.add_task_query()
+
     parser.add_argument(
         "--parallelism", type=int, help="使用するプロセス数（並列度）を指定してください。指定する場合は必ず'--yes'を指定してください。指定しない場合は、逐次的に処理します。"
     )
